Page Menu
Home
HEPForge
Search
Configure Global Search
Log In
Files
F10881621
No One
Temporary
Actions
View File
Edit File
Delete File
View Transforms
Subscribe
Mute Notifications
Award Token
Flag For Later
Size
19 KB
Subscribers
None
View Options
diff --git a/Helicity/Vertex/AbstractFFVTVertex.fh b/Helicity/Vertex/AbstractFFSTVertex.fh
copy from Helicity/Vertex/AbstractFFVTVertex.fh
copy to Helicity/Vertex/AbstractFFSTVertex.fh
--- a/Helicity/Vertex/AbstractFFVTVertex.fh
+++ b/Helicity/Vertex/AbstractFFSTVertex.fh
@@ -1,32 +1,32 @@
// -*- C++ -*-
//
-// This is the forward declaration of the AbstractFFVTVertex class.
+// This is the forward declaration of the AbstractFFSTVertex class.
//
-#ifndef HELICITY_AbstractFFVTVertex_FH
-#define HELICITY_AbstractFFVTVertex_FH
+#ifndef HELICITY_AbstractFFSTVertex_FH
+#define HELICITY_AbstractFFSTVertex_FH
#include "ThePEG/Config/Pointers.h"
namespace ThePEG {
namespace Helicity {
-class AbstractFFVTVertex;
+class AbstractFFSTVertex;
namespace VertexType {
typedef unsigned T;
/**
* Enum for this Lorentz structure
*/
- const T FFVT = 2235;
+ const T FFST = 2215;
}
}
}
namespace ThePEG {
-ThePEG_DECLARE_POINTERS(Helicity::AbstractFFVTVertex,AbstractFFVTVertexPtr);
+ThePEG_DECLARE_POINTERS(Helicity::AbstractFFSTVertex,AbstractFFSTVertexPtr);
}
#endif
diff --git a/Helicity/Vertex/AbstractVVVTVertex.fh b/Helicity/Vertex/AbstractSSSTVertex.fh
copy from Helicity/Vertex/AbstractVVVTVertex.fh
copy to Helicity/Vertex/AbstractSSSTVertex.fh
--- a/Helicity/Vertex/AbstractVVVTVertex.fh
+++ b/Helicity/Vertex/AbstractSSSTVertex.fh
@@ -1,32 +1,32 @@
// -*- C++ -*-
//
-// This is the forward declaration of the AbstractVVVTVertex class.
+// This is the forward declaration of the AbstractSSSTVertex class.
//
-#ifndef HELICITY_AbstractVVVTVertex_FH
-#define HELICITY_AbstractVVVTVertex_FH
+#ifndef HELICITY_AbstractSSSTVertex_FH
+#define HELICITY_AbstractSSSTVertex_FH
#include "ThePEG/Config/Pointers.h"
namespace ThePEG {
namespace Helicity {
-class AbstractVVVTVertex;
+class AbstractSSSTVertex;
namespace VertexType {
typedef unsigned T;
/**
* Enum for this Lorentz structure
*/
- const T VVVT = 3335;
+ const T SSST = 1115;
}
}
}
namespace ThePEG {
-ThePEG_DECLARE_POINTERS(Helicity::AbstractVVVTVertex,AbstractVVVTVertexPtr);
+ThePEG_DECLARE_POINTERS(Helicity::AbstractSSSTVertex,AbstractSSSTVertexPtr);
}
#endif
diff --git a/Helicity/Vertex/AbstractVVVTVertex.fh b/Helicity/Vertex/AbstractVVSTVertex.fh
copy from Helicity/Vertex/AbstractVVVTVertex.fh
copy to Helicity/Vertex/AbstractVVSTVertex.fh
--- a/Helicity/Vertex/AbstractVVVTVertex.fh
+++ b/Helicity/Vertex/AbstractVVSTVertex.fh
@@ -1,32 +1,32 @@
// -*- C++ -*-
//
-// This is the forward declaration of the AbstractVVVTVertex class.
+// This is the forward declaration of the AbstractVVSTVertex class.
//
-#ifndef HELICITY_AbstractVVVTVertex_FH
-#define HELICITY_AbstractVVVTVertex_FH
+#ifndef HELICITY_AbstractVVSTVertex_FH
+#define HELICITY_AbstractVVSTVertex_FH
#include "ThePEG/Config/Pointers.h"
namespace ThePEG {
namespace Helicity {
-class AbstractVVVTVertex;
+class AbstractVVSTVertex;
namespace VertexType {
typedef unsigned T;
/**
* Enum for this Lorentz structure
*/
- const T VVVT = 3335;
+ const T VVST = 3315;
}
}
}
namespace ThePEG {
-ThePEG_DECLARE_POINTERS(Helicity::AbstractVVVTVertex,AbstractVVVTVertexPtr);
+ThePEG_DECLARE_POINTERS(Helicity::AbstractVVSTVertex,AbstractVVSTVertexPtr);
}
#endif
diff --git a/Helicity/Vertex/Makefile.am b/Helicity/Vertex/Makefile.am
--- a/Helicity/Vertex/Makefile.am
+++ b/Helicity/Vertex/Makefile.am
@@ -1,32 +1,35 @@
SUBDIRS = Scalar Vector Tensor
noinst_LTLIBRARIES = libThePEGVertex.la
libThePEGVertex_la_SOURCES = \
VertexBase.cc VertexBase.h VertexBase.fh \
AbstractFFSVertex.h AbstractFFSVertex.fh AbstractFFSVertex.cc \
AbstractFFVVertex.h AbstractFFVVertex.fh AbstractFFVVertex.cc \
AbstractVVVVertex.h AbstractVVVVertex.fh AbstractVVVVertex.cc \
AbstractSSSVertex.h AbstractSSSVertex.fh AbstractSSSVertex.cc \
-AbstractSSSSVertex.h AbstractSSSSVertex.fh AbstractSSSSVertex.cc \
+AbstractSSSSVertex.h AbstractSSSSVertex.fh AbstractSSSSVertex.cc \
AbstractVSSVertex.h AbstractVSSVertex.fh AbstractVSSVertex.cc \
AbstractFFTVertex.h AbstractFFTVertex.fh AbstractFFTVertex.cc \
AbstractVVTVertex.h AbstractVVTVertex.fh AbstractVVTVertex.cc \
AbstractVVSVertex.h AbstractVVSVertex.fh AbstractVVSVertex.cc \
AbstractSSTVertex.h AbstractSSTVertex.fh AbstractSSTVertex.cc \
AbstractVVSSVertex.h AbstractVVSSVertex.fh AbstractVVSSVertex.cc \
AbstractVVVSVertex.h AbstractVVVSVertex.fh AbstractVVVSVertex.cc \
+AbstractFFSTVertex.h AbstractFFSTVertex.fh AbstractFFSTVertex.cc \
AbstractFFVTVertex.h AbstractFFVTVertex.fh AbstractFFVTVertex.cc \
+AbstractSSSTVertex.h AbstractSSSTVertex.fh AbstractSSSTVertex.cc \
+AbstractVVSTVertex.h AbstractVVSTVertex.fh AbstractVVSTVertex.cc \
AbstractVVVTVertex.h AbstractVVVTVertex.fh AbstractVVVTVertex.cc \
AbstractVVVVVertex.h AbstractVVVVVertex.fh AbstractVVVVVertex.cc \
-AbstractRFSVertex.h AbstractRFSVertex.fh AbstractRFSVertex.cc \
-AbstractRFVVertex.h AbstractRFVVertex.fh AbstractRFVVertex.cc \
+AbstractRFSVertex.h AbstractRFSVertex.fh AbstractRFSVertex.cc \
+AbstractRFVVertex.h AbstractRFVVertex.fh AbstractRFVVertex.cc \
AbstractFFVVVertex.h AbstractFFVVVertex.fh AbstractFFVVVertex.cc \
-AbstractFFVSVertex.h AbstractFFVSVertex.fh AbstractFFVSVertex.cc\
-AbstractFFSSVertex.h AbstractFFSSVertex.fh AbstractFFSSVertex.cc\
-AbstractFFFFVertex.h AbstractFFFFVertex.fh AbstractFFFFVertex.cc\
-AbstractRFSSVertex.h AbstractRFSSVertex.fh AbstractRFSSVertex.cc\
-AbstractRFVSVertex.h AbstractRFVSVertex.fh AbstractRFVSVertex.cc\
+AbstractFFVSVertex.h AbstractFFVSVertex.fh AbstractFFVSVertex.cc \
+AbstractFFSSVertex.h AbstractFFSSVertex.fh AbstractFFSSVertex.cc \
+AbstractFFFFVertex.h AbstractFFFFVertex.fh AbstractFFFFVertex.cc \
+AbstractRFSSVertex.h AbstractRFSSVertex.fh AbstractRFSSVertex.cc \
+AbstractRFVSVertex.h AbstractRFVSVertex.fh AbstractRFVSVertex.cc \
AbstractRFVVVertex.h AbstractRFVVVertex.fh AbstractRFVVVertex.cc
libThePEGVertex_la_LIBADD = Scalar/libThePEGSVertex.la \
Vector/libThePEGVVertex.la \
Tensor/libThePEGTVertex.la
File Metadata
Details
Attached
Mime Type
text/x-diff
Expires
Sat, May 3, 6:37 AM (1 d, 17 h)
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
4957449
Default Alt Text
(19 KB)
Attached To
rTHEPEGHG thepeghg
Event Timeline
Log In to Comment
diff --git a/Helicity/Vertex/AbstractFFVTVertex.cc b/Helicity/Vertex/AbstractFFSTVertex.cc
copy from Helicity/Vertex/AbstractFFVTVertex.cc
copy to Helicity/Vertex/AbstractFFSTVertex.cc
--- a/Helicity/Vertex/AbstractFFVTVertex.cc
+++ b/Helicity/Vertex/AbstractFFSTVertex.cc
@@ -1,26 +1,26 @@
// -*- C++ -*-
//
// This is the implementation of the non-inlined, non-templated member
// functions of the AbstractFFVTVertex class.
//
-#include "AbstractFFVTVertex.h"
+#include "AbstractFFSTVertex.h"
#include "ThePEG/Utilities/DescribeClass.h"
#include "ThePEG/Interface/ClassDocumentation.h"
using namespace ThePEG;
using namespace Helicity;
// The following static variable is needed for the type
// description system in ThePEG.
-DescribeAbstractNoPIOClass<AbstractFFVTVertex,VertexBase>
-describeThePEGAbstractFFVTVertex("ThePEG::AbstractFFVTVertex", "libThePEG.so");
+DescribeAbstractNoPIOClass<AbstractFFSTVertex,VertexBase>
+describeThePEGAbstractFFSTVertex("ThePEG::AbstractFFSTVertex", "libThePEG.so");
-void AbstractFFVTVertex::Init() {
+void AbstractFFSTVertex::Init() {
- static ClassDocumentation<AbstractFFVTVertex> documentation
- ("The AbstractFFVTVertex class is the base class for all "
- "fermion-fermion-vector-tensor interactions in ThePEG.");
+ static ClassDocumentation<AbstractFFSTVertex> documentation
+ ("The AbstractFFSTVertex class is the base class for all "
+ "fermion-fermion-scalar-tensor interactions in ThePEG.");
}
@@ -1,26 +1,26 @@
//
// This is the implementation of the non-inlined, non-templated member
-// functions of the AbstractFFVTVertex class.
+// functions of the AbstractFFSTVertex class.
//
diff --git a/Helicity/Vertex/AbstractFFVTVertex.h b/Helicity/Vertex/AbstractFFSTVertex.h
copy from Helicity/Vertex/AbstractFFVTVertex.h
copy to Helicity/Vertex/AbstractFFSTVertex.h
--- a/Helicity/Vertex/AbstractFFVTVertex.h
+++ b/Helicity/Vertex/AbstractFFSTVertex.h
@@ -1,78 +1,78 @@
// -*- C++ -*-
-#ifndef HELICITY_AbstractFFVTVertex_H
-#define HELICITY_AbstractFFVTVertex_H
+#ifndef HELICITY_AbstractFFSTVertex_H
+#define HELICITY_AbstractFFSTVertex_H
//
// This is the declaration of the AbstractFFVTVertex class.
//
#include "VertexBase.h"
-#include "ThePEG/Helicity/WaveFunction/VectorWaveFunction.h"
+#include "ThePEG/Helicity/WaveFunction/ScalarWaveFunction.h"
#include "ThePEG/Helicity/WaveFunction/TensorWaveFunction.h"
#include "ThePEG/Helicity/WaveFunction/SpinorWaveFunction.h"
#include "ThePEG/Helicity/WaveFunction/SpinorBarWaveFunction.h"
-#include "AbstractFFVTVertex.fh"
+#include "AbstractFFSTVertex.fh"
namespace ThePEG {
namespace Helicity {
/**
* The AbstractFFVTVertex class is the base class for all
* fermion-fermion-vector-tensor interactions in ThePEG.
*/
-class AbstractFFVTVertex: public VertexBase {
+class AbstractFFSTVertex: public VertexBase {
public:
/**
* Default constructor
*/
- AbstractFFVTVertex() : VertexBase(VertexType::FFVT) {}
+ AbstractFFSTVertex() : VertexBase(VertexType::FFST) {}
/**
* Members to calculate the helicity amplitude expressions for vertices
* and off-shell particles.
*/
//@{
/**
* Evalulate the vertex.
* @param q2 The scale \f$q^2\f$ for the coupling at the vertex.
* @param sp1 The wavefunction for the ferimon.
* @param sbar2 The wavefunction for the antifermion.
* @param vec3 The wavefunction for the vector.
* @param ten4 The wavefunction for the tensor.
*/
virtual Complex evaluate(Energy2 q2,const SpinorWaveFunction & sp1,
const SpinorBarWaveFunction & sbar2,
- const VectorWaveFunction & vec3,
+ const ScalarWaveFunction & sca3,
const TensorWaveFunction & ten4) = 0;
//@}
public:
/**
* The standard Init function used to initialize the interfaces.
* Called exactly once for each class by the class description system
* before the main function starts or
* when this class is dynamically loaded.
*/
static void Init();
private:
/**
* The assignment operator is private and must never be called.
* In fact, it should not even be implemented.
*/
- AbstractFFVTVertex & operator=(const AbstractFFVTVertex &);
+ AbstractFFSTVertex & operator=(const AbstractFFSTVertex &);
};
}
}
namespace ThePEG {
}
-#endif /* HELICITY_AbstractFFVTVertex_H */
+#endif /* HELICITY_AbstractFFSTVertex_H */
@@ -1,78 +1,78 @@
//
-// This is the declaration of the AbstractFFVTVertex class.
+// This is the declaration of the AbstractFFSTVertex class.
//
#include "VertexBase.h"
@@ -1,78 +1,78 @@
namespace Helicity {
/**
- * The AbstractFFVTVertex class is the base class for all
- * fermion-fermion-vector-tensor interactions in ThePEG.
+ * The AbstractFFSTVertex class is the base class for all
+ * fermion-fermion-scalar-tensor interactions in ThePEG.
*/
@@ -1,78 +1,78 @@
* @param sp1 The wavefunction for the ferimon.
* @param sbar2 The wavefunction for the antifermion.
- * @param vec3 The wavefunction for the vector.
+ * @param sca3 The wavefunction for the vector.
* @param ten4 The wavefunction for the tensor.
*/
diff --git a/Helicity/Vertex/AbstractVVVTVertex.cc b/Helicity/Vertex/AbstractSSSTVertex.cc
copy from Helicity/Vertex/AbstractVVVTVertex.cc
copy to Helicity/Vertex/AbstractSSSTVertex.cc
--- a/Helicity/Vertex/AbstractVVVTVertex.cc
+++ b/Helicity/Vertex/AbstractSSSTVertex.cc
@@ -1,26 +1,26 @@
// -*- C++ -*-
//
// This is the implementation of the non-inlined, non-templated member
// functions of the AbstractVVVTVertex class.
//
-#include "AbstractVVVTVertex.h"
+#include "AbstractSSSTVertex.h"
#include "ThePEG/Utilities/DescribeClass.h"
#include "ThePEG/Interface/ClassDocumentation.h"
using namespace ThePEG;
using namespace Helicity;
// The following static variable is needed for the type
// description system in ThePEG.
-DescribeAbstractNoPIOClass<AbstractVVVTVertex,VertexBase>
-describeThePEGAbstractVVVTVertex("ThePEG::AbstractVVVTVertex", "libThePEG.so");
+DescribeAbstractNoPIOClass<AbstractSSSTVertex,VertexBase>
+describeThePEGAbstractSSSTVertex("ThePEG::AbstractSSSTVertex", "libThePEG.so");
-void AbstractVVVTVertex::Init() {
+void AbstractSSSTVertex::Init() {
- static ClassDocumentation<AbstractVVVTVertex> documentation
- ("The AbstractVVVTVertex class is the base class for vector-vector-vector-tensor"
+ static ClassDocumentation<AbstractSSSTVertex> documentation
+ ("The AbstractSSSTVertex class is the base class for scalar-scalar-scalar-tensor"
" interactions in ThePEG");
}
@@ -1,26 +1,26 @@
//
// This is the implementation of the non-inlined, non-templated member
-// functions of the AbstractVVVTVertex class.
+// functions of the AbstractSSSTVertex class.
//
diff --git a/Helicity/Vertex/AbstractVVVTVertex.h b/Helicity/Vertex/AbstractSSSTVertex.h
copy from Helicity/Vertex/AbstractVVVTVertex.h
copy to Helicity/Vertex/AbstractSSSTVertex.h
--- a/Helicity/Vertex/AbstractVVVTVertex.h
+++ b/Helicity/Vertex/AbstractSSSTVertex.h
@@ -1,75 +1,75 @@
// -*- C++ -*-
-#ifndef HELICITY_AbstractVVVTVertex_H
-#define HELICITY_AbstractVVVTVertex_H
+#ifndef HELICITY_AbstractSSSTVertex_H
+#define HELICITY_AbstractSSSTVertex_H
//
// This is the declaration of the AbstractVVVTVertex class.
//
#include "VertexBase.h"
-#include "ThePEG/Helicity/WaveFunction/VectorWaveFunction.h"
+#include "ThePEG/Helicity/WaveFunction/ScalarWaveFunction.h"
#include "ThePEG/Helicity/WaveFunction/TensorWaveFunction.h"
-#include "AbstractVVVTVertex.fh"
+#include "AbstractSSSTVertex.fh"
namespace ThePEG {
namespace Helicity {
/**
* The AbstractVVVTVertex class is the base class for all vector-vector-vector-tensor
* interactions in ThePEG.
*/
-class AbstractVVVTVertex: public VertexBase {
+class AbstractSSSTVertex: public VertexBase {
public:
/**
* Default constructor
*/
- AbstractVVVTVertex() : VertexBase(VertexType::VVVT) {}
+ AbstractSSSTVertex() : VertexBase(VertexType::SSST) {}
/**
* Members to calculate the helicity amplitude expressions for vertices
* and off-shell particles.
*/
//@{
/**
* Evalulate the vertex.
* @param q2 The scale \f$q^2\f$ for the coupling at the vertex.
* @param vec1 The wavefunction for the first vector.
* @param vec2 The wavefunction for the second vector.
* @param vec3 The wavefunction for the third vector.
* @param ten4 The wavefunction for the tensor.
*/
- virtual Complex evaluate(Energy2 q2,const VectorWaveFunction & vec1,
- const VectorWaveFunction & vec2,
- const VectorWaveFunction & vec3,
+ virtual Complex evaluate(Energy2 q2,const ScalarWaveFunction & sca1,
+ const ScalarWaveFunction & sca2,
+ const ScalarWaveFunction & sca3,
const TensorWaveFunction & ten4) = 0;
//@}
public:
/**
* The standard Init function used to initialize the interfaces.
* Called exactly once for each class by the class description system
* before the main function starts or
* when this class is dynamically loaded.
*/
static void Init();
private:
/**
* The assignment operator is private and must never be called.
* In fact, it should not even be implemented.
*/
- AbstractVVVTVertex & operator=(const AbstractVVVTVertex &);
+ AbstractSSSTVertex & operator=(const AbstractSSSTVertex &);
};
}
}
namespace ThePEG {
}
-#endif /* HELICITY_AbstractVVVTVertex_H */
+#endif /* HELICITY_AbstractSSSTVertex_H */
@@ -1,75 +1,75 @@
//
-// This is the declaration of the AbstractVVVTVertex class.
+// This is the declaration of the AbstractSSSTVertex class.
//
#include "VertexBase.h"
@@ -1,75 +1,75 @@
namespace Helicity {
/**
- * The AbstractVVVTVertex class is the base class for all vector-vector-vector-tensor
+ * The AbstractSSSTVertex class is the base class for all scalar-scalar-scalar-tensor
* interactions in ThePEG.
*/
@@ -1,75 +1,75 @@
* Evalulate the vertex.
* @param q2 The scale \f$q^2\f$ for the coupling at the vertex.
- * @param vec1 The wavefunction for the first vector.
- * @param vec2 The wavefunction for the second vector.
- * @param vec3 The wavefunction for the third vector.
+ * @param sca1 The wavefunction for the first scalar.
+ * @param sca2 The wavefunction for the second scalar.
+ * @param sca3 The wavefunction for the third scalar.
* @param ten4 The wavefunction for the tensor.
*/
diff --git a/Helicity/Vertex/AbstractVVVTVertex.cc b/Helicity/Vertex/AbstractVVSTVertex.cc
copy from Helicity/Vertex/AbstractVVVTVertex.cc
copy to Helicity/Vertex/AbstractVVSTVertex.cc
--- a/Helicity/Vertex/AbstractVVVTVertex.cc
+++ b/Helicity/Vertex/AbstractVVSTVertex.cc
@@ -1,26 +1,26 @@
// -*- C++ -*-
//
// This is the implementation of the non-inlined, non-templated member
// functions of the AbstractVVVTVertex class.
//
-#include "AbstractVVVTVertex.h"
+#include "AbstractVVSTVertex.h"
#include "ThePEG/Utilities/DescribeClass.h"
#include "ThePEG/Interface/ClassDocumentation.h"
using namespace ThePEG;
using namespace Helicity;
// The following static variable is needed for the type
// description system in ThePEG.
-DescribeAbstractNoPIOClass<AbstractVVVTVertex,VertexBase>
-describeThePEGAbstractVVVTVertex("ThePEG::AbstractVVVTVertex", "libThePEG.so");
+DescribeAbstractNoPIOClass<AbstractVVSTVertex,VertexBase>
+describeThePEGAbstractVVSTVertex("ThePEG::AbstractVVSTVertex", "libThePEG.so");
-void AbstractVVVTVertex::Init() {
+void AbstractVVSTVertex::Init() {
- static ClassDocumentation<AbstractVVVTVertex> documentation
- ("The AbstractVVVTVertex class is the base class for vector-vector-vector-tensor"
+ static ClassDocumentation<AbstractVVSTVertex> documentation
+ ("The AbstractVVSTVertex class is the base class for vector-vector-scalar-tensor"
" interactions in ThePEG");
}
@@ -1,26 +1,26 @@
//
// This is the implementation of the non-inlined, non-templated member
-// functions of the AbstractVVVTVertex class.
+// functions of the AbstractVVSTVertex class.
//
diff --git a/Helicity/Vertex/AbstractVVVTVertex.h b/Helicity/Vertex/AbstractVVSTVertex.h
copy from Helicity/Vertex/AbstractVVVTVertex.h
copy to Helicity/Vertex/AbstractVVSTVertex.h
--- a/Helicity/Vertex/AbstractVVVTVertex.h
+++ b/Helicity/Vertex/AbstractVVSTVertex.h
@@ -1,75 +1,76 @@
// -*- C++ -*-
-#ifndef HELICITY_AbstractVVVTVertex_H
-#define HELICITY_AbstractVVVTVertex_H
+#ifndef HELICITY_AbstractVVSTVertex_H
+#define HELICITY_AbstractVVSTVertex_H
//
// This is the declaration of the AbstractVVVTVertex class.
//
#include "VertexBase.h"
+#include "ThePEG/Helicity/WaveFunction/ScalarWaveFunction.h"
#include "ThePEG/Helicity/WaveFunction/VectorWaveFunction.h"
#include "ThePEG/Helicity/WaveFunction/TensorWaveFunction.h"
-#include "AbstractVVVTVertex.fh"
+#include "AbstractVVSTVertex.fh"
namespace ThePEG {
namespace Helicity {
/**
* The AbstractVVVTVertex class is the base class for all vector-vector-vector-tensor
* interactions in ThePEG.
*/
-class AbstractVVVTVertex: public VertexBase {
+class AbstractVVSTVertex: public VertexBase {
public:
/**
* Default constructor
*/
- AbstractVVVTVertex() : VertexBase(VertexType::VVVT) {}
+ AbstractVVSTVertex() : VertexBase(VertexType::VVST) {}
/**
* Members to calculate the helicity amplitude expressions for vertices
* and off-shell particles.
*/
//@{
/**
* Evalulate the vertex.
* @param q2 The scale \f$q^2\f$ for the coupling at the vertex.
* @param vec1 The wavefunction for the first vector.
* @param vec2 The wavefunction for the second vector.
* @param vec3 The wavefunction for the third vector.
* @param ten4 The wavefunction for the tensor.
*/
virtual Complex evaluate(Energy2 q2,const VectorWaveFunction & vec1,
const VectorWaveFunction & vec2,
- const VectorWaveFunction & vec3,
+ const ScalarWaveFunction & sca3,
const TensorWaveFunction & ten4) = 0;
//@}
public:
/**
* The standard Init function used to initialize the interfaces.
* Called exactly once for each class by the class description system
* before the main function starts or
* when this class is dynamically loaded.
*/
static void Init();
private:
/**
* The assignment operator is private and must never be called.
* In fact, it should not even be implemented.
*/
- AbstractVVVTVertex & operator=(const AbstractVVVTVertex &);
+ AbstractVVSTVertex & operator=(const AbstractVVSTVertex &);
};
}
}
namespace ThePEG {
}
-#endif /* HELICITY_AbstractVVVTVertex_H */
+#endif /* HELICITY_AbstractVVSTVertex_H */
@@ -1,75 +1,76 @@
//
-// This is the declaration of the AbstractVVVTVertex class.
+// This is the declaration of the AbstractVVSTVertex class.
//
#include "VertexBase.h"
@@ -1,75 +1,76 @@
namespace Helicity {
/**
- * The AbstractVVVTVertex class is the base class for all vector-vector-vector-tensor
+ * The AbstractVVSTVertex class is the base class for all vector-vector-scalar-tensor
* interactions in ThePEG.
*/
@@ -1,75 +1,76 @@
* @param vec1 The wavefunction for the first vector.
* @param vec2 The wavefunction for the second vector.
- * @param vec3 The wavefunction for the third vector.
+ * @param sca3 The wavefunction for the third vector.
* @param ten4 The wavefunction for the tensor.
*/